# Reajuste Salarial

Description. 
The package Reajuste Salarial is used to:
	- Calcular o reajuste salarial
	-

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name

```bash
pip install Reajuste Salarial
```

## Usage

```python
from package_name.module1_name import file1_name
file1_name.my_function()
```

## Author
William Reimann
## License
[MIT](https://choosealicense.com/licenses/mit/)